# आरंभ करें!

पाइथन और आर के लिए एक आधुनिक विकास वातावरण के लिए Rapunzel में आपका स्वागत है। यहां कुछ हैंडी कीबोर्ड शॉर्टकट हैं।

## परियोजना फ़ोल्डरों और फ़ाइलों के साथ काम करना

- [`Ctrl+Shift+O`: प्रोजेक्ट फ़ोल्डर खोलें](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`: परियोजना फ़ोल्डरों से फ़ाइल खोलें](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`: खाली दस्तावेज़ बनाएं](opensesame://event.ide_new_file)

## त्वरित चीज़ें करने के लिए

- [`Ctrl+Shift+P`: कमांड पैलेट सक्रिय करें](opensesame://event.command_palette_activate)
- `Ctrl+R`: फ़ंक्शन या क्लास में जाएँ

## कोड चलाना

- `F5`: परियोजना या फ़ाइल चलाएं
- `F9`: चयन, सेल, या वर्तमान लाइन चलाएँ